@@ -571,6 +571,7 @@ typedef struct {
   int32 printcount;               /* Chars printed this line (used by PRINT) */
   int32 printwidth;               /* Width of line (used by PRINT) */
   int32 recdepth;                 /* Record depth of FN and flood-fill recursion */
+  int32 xtab;                     /* X value of TAB(X,Y) */
   byte *lastsearch;               /* Place last proc/fn search reached */
   int32 linecount;                /* Used when reading a Basic program or library into memory */
   variable staticvars[STDVARS];   /* Static integer variables @%-Z% */
@@ -613,6 +614,7 @@ typedef struct {
   boolean pseudovarsunsigned; /* Unsigned pseudovars on 32-bit */
   boolean tekenabled;         /* Tektronix enabled in text mode (default: no) */
   boolean networking;         /* TRUE if networking is available */
+  boolean lowercasekeywords;  /* Allow lower-case keywords? */
 #ifdef USE_SDL
   byte *modescreen_ptr;       /* Mode screen pointer to pixels memory */
   uint32 modescreen_sz;       /* Mode screen size */
