@@ -22,7 +22,6 @@
 **      This file contains the main interpreter command loop
 */
 
-#include "target.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -30,6 +29,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <time.h>
+#include "target.h"
 #ifndef TARGET_RISCOS
 #include <pthread.h>
 #endif
@@ -261,6 +261,7 @@ static void init1(void) {
   basicvars.loadpath = NIL;
   basicvars.argcount = 0;
   basicvars.recdepth = 0;
+  basicvars.xtab = 0;
   basicvars.arglist = NIL;            /* List of command line arguments */
   basicvars.maxrecdepth = MAXRECDEPTH;
   arglast = NIL;                      /* End of list of command line arguments */
@@ -421,6 +422,8 @@ static void check_configfile() {
     } else if(!strncmp(item, "swsurface", 10)) {
       basicvars.runflags.swsurface=TRUE;
 #endif
+    } else if(!strncmp(item,"lowercase",10)) {
+      matrixflags.lowercasekeywords = TRUE;
     } else if(!strncmp(item, "ignore", 8)) {
       basicvars.runflags.flag_cosmetic = FALSE;
     } else if(!strncmp(item, "strict", 7)) {
@@ -545,6 +548,8 @@ static void check_cmdline(int argc, char *argv[]) {
           }
         }
       }
+      else if (optchar=='l' && tolower(*(p+2))=='c' && tolower(*(p+3))=='k')
+        matrixflags.lowercasekeywords=1;                /* -lck */
       else if (optchar=='t')                            /* -tek - enable Tek graphics */
         matrixflags.tekenabled=1;
       else if (optchar=='i' && tolower(*(p+2))=='g')    /* -ignore  Ignore cosmetic errors */
