@@ -32,6 +32,7 @@
 #include <ctype.h>
 #include "common.h"
 #include "target.h"
+#include "editor.h"
 #include "basicdefs.h"
 #include "errors.h"
 #include "variables.h"
@@ -521,7 +522,7 @@ static int32 read_bbcfile(FILE *bbcfile, byte *base, byte *limit, int32 ftype) {
 ** the end of the file. It could indicate an I/O error on the file.
 */
 static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean silent) {
-  int length;
+  int length, lck;
   byte *filebase;
   char *result;
   byte tokenline[MAXSTATELEN];
@@ -561,6 +562,8 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
       return 0;
     }
   }
+  lck=matrixflags.lowercasekeywords;
+  matrixflags.lowercasekeywords=0;
   needsnumbers = FALSE;         /* This will be set by tokenise_line() above */
   basicvars.linecount = 0;      /* Number of line being read from file */
   filebase = base;
@@ -569,7 +572,7 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
     result = gzgets(gzipfile, basicvars.stringwork, INPUTLEN);
   else
 #endif
-  result = fgets(basicvars.stringwork, INPUTLEN, textfile);
+  result = multifgets(basicvars.stringwork, INPUTLEN, textfile);
     if (result!=NIL && basicvars.stringwork[0]=='#') {  /* Ignore first line if it starts with a '#' */
     basicvars.runflags.quitatend=basicvars.runflags.loadngo;
 #ifdef HAVE_ZLIB_H
@@ -577,7 +580,7 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
       result = gzgets(gzipfile, basicvars.stringwork, INPUTLEN);
     else
 #endif
-    result = fgets(basicvars.stringwork, INPUTLEN, textfile);
+    result = multifgets(basicvars.stringwork, INPUTLEN, textfile);
   }
   while (result!=NIL) {
     basicvars.linecount++;
@@ -605,6 +608,7 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
 #endif
         fclose(textfile);
         basicvars.misc_flags.badprogram=1; /* The program is incomplete, thus corrupt */
+        matrixflags.lowercasekeywords=lck;
         error(ERR_NOROOM);
         return 0;
       }
@@ -616,7 +620,7 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
       result = gzgets(gzipfile, basicvars.stringwork, INPUTLEN);
     else
 #endif
-    result = fgets(basicvars.stringwork, INPUTLEN, textfile);
+    result = multifgets(basicvars.stringwork, INPUTLEN, textfile);
   }
 #ifdef HAVE_ZLIB_H
   if (gzipped)
@@ -626,6 +630,7 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
   fclose(textfile);
   basicvars.linecount = 0;
   if (base+ENDMARKSIZE>=limit) {
+    matrixflags.lowercasekeywords=lck;
     error(ERR_NOROOM);
     return 0;
   }
@@ -634,6 +639,7 @@ static int32 read_textfile(FILE *textfile, byte *base, byte *limit, boolean sile
     if (!basicvars.runflags.loadngo) emulate_printf("Line numbers added to program\r\n");
     renumber_program(filebase, 1, 1);
   }
+  matrixflags.lowercasekeywords=lck;
   return ALIGN(base-filebase+ENDMARKSIZE);
 }
 
@@ -1017,3 +1023,25 @@ void edit_line(void) {
     insert_line(thisline);
   }
 }
+
+/*
+** Implementation of fgets() that handles both 0x0D and 0x0A line endings
+**/
+char *multifgets(char *mfbuf, int bufsz, FILE *handle) {
+  int c = 0;
+  char* cs;
+  cs = mfbuf;
+
+  while(--bufsz > 0 && (c = getc(handle)) != EOF) {
+    // put the input char into the current pointer position, then increment it
+    // if a newline entered, break
+    if ((c == '\n') || (c == '\r')) {
+      c='\n';
+      if (cs == mfbuf) continue; /* If CR or LF at start of line, get next character */
+    }
+    if ((*cs++ = c) == '\n') break;          
+  }
+
+  *cs = '\0';
+  return (c == EOF && cs == mfbuf) ? NULL : mfbuf;
+}
