@@ -307,7 +307,12 @@ void announce(void) {
 #ifndef NONET
 #ifndef BRANDY_NOVERCHECK
   if (matrixflags.checknewver) {
-    if (checkfornewer()) emulate_printf("A newer version is available!\r\n\n");
+    switch (checkfornewer()) {
+      case 1:emulate_printf("A newer version is available!\r\n\n");
+              break;
+      case 2:emulate_printf("Error retrieving version info, use '-nocheck' to avoid hangs.\r\n\n");
+      default: break;
+    }
   }
 #endif /* BRANDY_NOVERCHECK */
 #endif /* NONET */
@@ -387,6 +392,7 @@ void show_help(void) {
 #else
   printf("  -ignore        Ignore 'unsupported feature' where possible\n");
 #endif
+  printf("  -lck           Allow use of lowercase keywords\n");
 #ifndef TARGET_RISCOS
   printf("  -nostar        Do not check OSCLI for internal *-commands, instead pass all\n");
   printf("                 commands to the underlying operating system.\n");
