@@ -19,8 +19,8 @@
 ** Boston, MA 02111-1307, USA.
 **
 **
-**	This file defines the functions and so forth associated with memory
-**	manangement
+**      This file defines the functions and so forth associated with memory
+**      manangement
 */
 
 #ifndef __heap_h
@@ -28,15 +28,22 @@
 
 #include "common.h"
 
-#define STACKBUFFER 256		/* Minimum space allowed between Basic's stack and variables */
+#define STACKBUFFER 256         /* Minimum space allowed between Basic's stack and variables */
 
 extern boolean init_heap(void);
 extern void release_heap(void);
 extern boolean init_workspace(size_t);
 extern void release_workspace(void);
 extern void *allocmem(size_t, boolean);
-extern boolean returnable(void *, int32);
+//extern boolean returnable(void *, int32);
 extern void freemem(void *, int32);
 extern void clear_heap(void);
 
+/*
+** 'returnable' is called to check if the block at 'where' is the
+** last item allocated on the heap and can therefore be returned
+** to it.
+*/
+#define returnable(x,y) (CAST(x, byte *)+ALIGN(y)==basicvars.vartop)
+
 #endif
