@@ -216,7 +216,7 @@ void emulate_printf(char *format, ...) {
   char text [MAXSTRING];
   int n;
   va_start(parms, format);
-  length = vsprintf(text, format, parms);
+  length = vsnprintf(text, MAXSTRING, format, parms);
   va_end(parms);
   echo_off();
   for (n = 0; n < length; n++) emulate_vdu(text[n]);
